Documentation
¶
Overview ¶
Package loggingexporter exports data to console as logs.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory creates a factory for Logging exporter
Types ¶
type Config ¶
type Config struct {
// LogLevel defines log level of the logging exporter; options are debug, info, warn, error.
// Deprecated: Use `Verbosity` instead.
LogLevel zapcore.Level `mapstructure:"loglevel,omitempty"`
// Verbosity defines the logging exporter verbosity.
Verbosity configtelemetry.Level `mapstructure:"verbosity,omitempty"`
// SamplingInitial defines how many samples are initially logged during each second.
SamplingInitial int `mapstructure:"sampling_initial"`
// SamplingThereafter defines the sampling rate after the initial samples are logged.
SamplingThereafter int `mapstructure:"sampling_thereafter"`
// contains filtered or unexported fields
}
Config defines configuration for logging exporter.
Click to show internal directories.
Click to hide internal directories.