nopexporter

package module
v0.150.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: Apache-2.0 Imports: 6 Imported by: 8

README

No-op Exporter

Status
Stability alpha: profiles
beta: traces, metrics, logs
Distributions core, contrib, k8s
Issues Open issues Closed issues
Code Owners @evan-bradley

Serves as a placeholder exporter in a pipeline. This can be useful if you want to e.g. start a Collector with only extensions enabled, or for testing Collector pipeline throughput without worrying about an exporter.

Getting Started

All that is required to enable the No-op exporter is to include it in the exporter definitions. It takes no configuration.

exporters:
  nop: {} # Explicitly set in case the config is re-serialized (e.g. with the Operator)

Documentation

Overview

Package nopexporter serves as a placeholder exporter.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFactory

func NewFactory() exporter.Factory

NewFactory returns an exporter.Factory that constructs nop exporters.

Types

This section is empty.

Directories

Path Synopsis
internal

Jump to