Documentation
¶
Overview ¶
Package otlpexporter exports data by using the OTLP format to a gRPC endpoint.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFactory ¶
NewFactory creates a factory for OTLP exporter.
Types ¶
type Config ¶
type Config struct {
TimeoutConfig exporterhelper.TimeoutConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct.
QueueConfig configoptional.Optional[exporterhelper.QueueBatchConfig] `mapstructure:"sending_queue"`
RetryConfig configretry.BackOffConfig `mapstructure:"retry_on_failure"`
ClientConfig configgrpc.ClientConfig `mapstructure:",squash"` // squash ensures fields are correctly decoded in embedded struct.
// contains filtered or unexported fields
}
Config defines configuration for OTLP exporter.
Click to show internal directories.
Click to hide internal directories.