Documentation
¶
Index ¶
- type CreateProfilesFunc
- type Factory
- type FactoryOption
- func WithDeprecatedTypeAlias(alias component.Type) FactoryOption
- func WithLogs(createLogs exporter.CreateLogsFunc, sl component.StabilityLevel) FactoryOption
- func WithMetrics(createMetrics exporter.CreateMetricsFunc, sl component.StabilityLevel) FactoryOption
- func WithProfiles(createProfiles CreateProfilesFunc, sl component.StabilityLevel) FactoryOption
- func WithTraces(createTraces exporter.CreateTracesFunc, sl component.StabilityLevel) FactoryOption
- type Profiles
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateProfilesFunc ¶
type CreateProfilesFunc func(context.Context, exporter.Settings, component.Config) (Profiles, error)
CreateProfilesFunc is the equivalent of Factory.CreateProfiles.
type Factory ¶
type Factory interface {
exporter.Factory
// CreateProfiles creates a Profiles exporter based on this config.
// If the exporter type does not support tracing,
// this function returns the error [pipeline.ErrSignalNotSupported].
CreateProfiles(ctx context.Context, set exporter.Settings, cfg component.Config) (Profiles, error)
// ProfilesStability gets the stability level of the Profiles exporter.
ProfilesStability() component.StabilityLevel
}
func NewFactory ¶
func NewFactory(cfgType component.Type, createDefaultConfig component.CreateDefaultConfigFunc, options ...FactoryOption) Factory
NewFactory creates a wrapped exporter.Factory with experimental capabilities.
type FactoryOption ¶
type FactoryOption interface {
// contains filtered or unexported methods
}
FactoryOption apply changes to ReceiverOptions.
func WithDeprecatedTypeAlias ¶ added in v0.144.0
func WithDeprecatedTypeAlias(alias component.Type) FactoryOption
WithDeprecatedTypeAlias configures a deprecated type alias for the exporter. Only one alias is supported per exporter. When the alias is used in configuration, a deprecation warning is automatically logged.
func WithLogs ¶
func WithLogs(createLogs exporter.CreateLogsFunc, sl component.StabilityLevel) FactoryOption
WithLogs overrides the default "error not supported" implementation for CreateLogs and the default "undefined" stability level.
func WithMetrics ¶
func WithMetrics(createMetrics exporter.CreateMetricsFunc, sl component.StabilityLevel) FactoryOption
WithMetrics overrides the default "error not supported" implementation for CreateMetrics and the default "undefined" stability level.
func WithProfiles ¶
func WithProfiles(createProfiles CreateProfilesFunc, sl component.StabilityLevel) FactoryOption
WithProfiles overrides the default "error not supported" implementation for CreateProfilesExporter and the default "undefined" stability level.
func WithTraces ¶
func WithTraces(createTraces exporter.CreateTracesFunc, sl component.StabilityLevel) FactoryOption
WithTraces overrides the default "error not supported" implementation for CreateTraces and the default "undefined" stability level.